package com.aurellem.capture.examples;

import java.io.File;
import java.io.IOException;

import jme3test.helloworld.HelloAudio;
import jme3test.helloworld.HelloJME3;
import jme3test.niftygui.TestNiftyExamples;
import jme3test.water.TestPostWater;

import com.aurellem.capture.Capture;
import com.aurellem.capture.IsoTimer;
import com.jme3.app.SimpleApplication;


/**
 * 
 * Demonstrates how to use basic Audio/Video capture with a jMonkeyEngine 
 * application. You can use these techniques to make high quality cutscenes
 * or demo videos, even on very slow laptops.
 * 
 * @author Robert McIntyre
 *
 */

public class Basic {
	
	public static void basicVideo() throws IOException{
		File video = File.createTempFile("HelloJME3", ".avi");
		System.out.println("Saving video to: " + video.getCanonicalPath());
		SimpleApplication app = new HelloJME3();
		app.setTimer(new IsoTimer(60));
		app.setShowSettings(false);
		
		Capture.captureVideo(app, video);
		app.start();
	}
	
	public static void basicVideoGUI() throws IOException {
		File video = File.createTempFile("GUI", ".avi");
		System.out.println("Saving video to: " + video.getCanonicalPath());
		SimpleApplication app = new TestNiftyExamples();
		app.setTimer(new IsoTimer(60));
		app.setShowSettings(false);
		
		Capture.captureVideo(app, video);
		app.start();
	}
	
	public static void basicAudio() throws IOException{
		File audio = File.createTempFile("BasicAudio", ".wav");
		System.out.println("Saving audio to: " + audio.getCanonicalPath());
		SimpleApplication app = new HelloAudio();
		app.setTimer(new IsoTimer(60));
		app.setShowSettings(false);
		
		// you will not hear the audio while it is being captured.
		Capture.captureAudio(app, audio);
		
		app.start();
	}
	
	public static void basicAudioVideo() throws IOException{
		File video = new File("/home/r/tmp/basicVideo.avi");
		File audio = new File("/home/r/tmp/basicAudio.wav");
		
		SimpleApplication app = new TestPostWater();
		app.setTimer(new IsoTimer(60));
		app.setShowSettings(false);
		
		Capture.captureVideo(app, video);
		Capture.captureAudio(app, audio);
		
		app.start();
	}
	
	
	public static void main(String[] ignore) throws IOException{
		basicVideo();
		basicVideoGUI();
		basicAudio();
		basicAudioVideo();
	}
}
